#include <avr/io.h>

void ADC_init(void)
{
    ADMUX = 0;

    ADMUX |= (1 << REFS0); // tensiunea de referinta AVCC = 5 V
    
    ADCSRA = (1 << ADEN) | (7 << ADPS0);

}

/*
    Returns the result of an ADC conversion. 
    Starts a conversion and waits for the result when not using interrupts.
*/
int ADC_get(uint8_t channel)
{
    ADMUX = (ADMUX & ~(0x1f << MUX0)) | channel;

    ADCSRA |= (1 << ADSC);

    while(ADCSRA & (1 << ADSC));

    return ADC;
}

/*
    Converts a value given by the ADC to celsius grades.
*/
double ADC_temp(int raw)
{
    // din masuratori => grafic + sistem + aflare ecuatie de forma y = a * x + b
    // tensiunea este pe x (in volti)
    // f(tensiune) = temperatura este pe y (in grade Celsius)
    double voltage = (double)(raw * 5.0 / 1024.0);
    double a = 338.1685;
    double b = -1048.1484;
    return (double)(a * voltage + b);

}
