#include <avr/io.h>
#include <util/delay.h>
#include <stdlib.h>
#include <stdio.h>
#include "Nokia5110/Nokia5110.h"
#include "adc.h"
#include <avr/interrupt.h>
// senorul analogic de temperatura
#define LIGHT_SENSOR 0

volatile double temp_dorita = 13.0;
/***************Rutina de tratare a intreruperii*********************/
ISR(PCINT1_vect)
{
	// daca este apasat PB0 (buton de -- pentru temperatura)
    if ((PINB & (1 << PB0)) == 0)
    {
    	/* turn off led */
		PORTD &= ~(1 << PD7);
		// decrementez temperatura dorita,afisata
		temp_dorita = temp_dorita - 0.2;
    }
    // daca este apasat PB1 (buton de ++ pentru temperatura)
    if ((PINB & (1 << PB1)) == 0)
    {
    	/* turn on led */
		PORTD |= (1 << PD7);
		// incrementez temperatura dorita,afisata
		temp_dorita = temp_dorita + 0.2;
    }
}

void setup() {
	/* set output pin (led din placa de baza)*/
	DDRD |= (1 << PD7);

	//PB0 si PB1 sunt ca intrare
	//fara pull up, le las pe 0
	//fara PORTB |= (1 << PB0);
    DDRB &= ~(1 << PB0);
    DDRB &= ~(1 << PB1);

    // Activez PIN CHANGE INTERRUPT ENABLE pentru PCINT15:8 (portul B)
    PCICR |= (1 << PCIE1);
    // Activez intreruperea pe butoanele PB0 si PB1
    PCMSK1 |= (1 << PCINT8);
    PCMSK1 |= (1 << PCINT9);
    sei();
}

int main(void) {
	double celsius_sum = 0.0;
	unsigned int contor = 1;
	setup();
	LCD_init();
	LCD_clear();
	ADC_init();
	char buffer[20];
	//set output pin, PB2, iesire pentru modulul de racire
	DDRB |= (1 << PB2);
	PORTB |= (1 << PB2);
	// setez modulul de racire sa porneasca initial
	PORTB |= (1 << PB2);

	while(1) {

		// x = 0; y = 0
		LCD_write_string(0, 0, "BeRe ReCe-DAM-");

		// x = 0, y = 2
		sprintf(buffer, "%s", "Actual(C):");
		LCD_write_string(0 , 2, buffer);

		double celsius = ADC_temp(ADC_get(LIGHT_SENSOR));

		/**Afisez media a 100 de valori consecutive **/
		/** altfel, valorile aratate ar fi schimbate foarte rapid **/
		/** pe lcd, si abia se poate citi valoarea **/

		if (contor % 100 == 0){
			// insumez si valoarea actuala
			// afisez suma ultimelor 100 valori
			celsius_sum += celsius;
			double rez = celsius_sum / 100.0;
			dtostrf(rez, 3, 5,buffer);
			LCD_write_string(0 , 3, buffer);
			celsius_sum = 0.0;

			// verific daca este cazul sa pornesc/opresc racirea
			if ((rez <= temp_dorita)) {
				// setez modulul de racire sa se opreasca
				PORTB &= ~(1 << PB2);
			} else {
				// setez modulul de racire sa porneasca
				PORTB |= (1 << PB2);
			}

		} else {
			celsius_sum += celsius;
		}
		contor++;

		// Valoarea pe care o doresc in frigider.
		// Initial este 13 si poate fi incrementata/decrementata 
		// cu 0.2 unitati
		sprintf(buffer, "%s", "Setat(C):");
		LCD_write_string(0 , 4, buffer);

		dtostrf(temp_dorita, 3, 5,buffer);
		LCD_write_string(0 , 5, buffer);

	}

	return 0;
}

